aboutsummaryrefslogtreecommitdiff
path: root/video/codecs/qdm2.cpp
diff options
context:
space:
mode:
authorEugene Sandulenko2011-01-23 19:08:09 +0000
committerEugene Sandulenko2011-01-23 19:08:09 +0000
commitcaa6684752a310e916b179125a4125a8b3be36f0 (patch)
treedc364d58619b297194bc5d0673b694c34fb51b6c /video/codecs/qdm2.cpp
parent3d15871ee2d6a9c0ce4819a6ab5925638bafa8b9 (diff)
downloadscummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.gz
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.bz2
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.zip
VIDEO: Move video classes to Video:: namespace
svn-id: r55479
Diffstat (limited to 'video/codecs/qdm2.cpp')
-rw-r--r--video/codecs/qdm2.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/video/codecs/qdm2.cpp b/video/codecs/qdm2.cpp
index 6721788d8c..eac1954435 100644
--- a/video/codecs/qdm2.cpp
+++ b/video/codecs/qdm2.cpp
@@ -37,7 +37,7 @@
#include "common/stream.h"
#include "common/system.h"
-namespace Graphics {
+namespace Video {
enum {
SOFTCLIP_THRESHOLD = 27600,
@@ -3282,6 +3282,6 @@ Audio::AudioStream *makeQDM2Stream(Common::SeekableReadStream *stream, Common::S
return new QDM2Stream(stream, extraData);
}
-} // End of namespace Graphics
+} // End of namespace Video
#endif